/*
 * (C) A.S. Software, Axel Schmidt, Lehringen 1a, D-27308 Kirchlinteln 2001
 *     http://www.assoftware.de
 * 
 * Demonstration der Hilfsfunktionen fr das CT_API Rexxinterface:
 *      CTAPI_StrToHexStr()
 *      CTAPI_HexStrToStr()
 *      CTAPI_SubHexStr()
 *      CTAPI_HexByteToInt()
 *      CTAPI_IntToHexByte()
 */
'@echo off'

/* 
 * Load CT_REXX Proc. 
 */
call RxFuncAdd 'CTAPI_LoadAllProc', 'CT_REXX', 'CTAPI_LoadAllProc'
call CTAPI_LoadAllProc 


/*
 * CTAPI_StrToHexStr()
 *
 * Uebersetzt einen 'String' in eine 'Hex-String'
 *
 * Parameter:
 *     1. Die zu uebersetzende Zeichenkette
 *     2. (optional) Zeichen, das beim uebersetzen in '00' Hex geaendert 
 *        werden soll. Wenn dieser Parameter nicht angegeben ist, 
 *        wird 0xfa in '00' uebersetzt. Sollen keine Zeichen geaendert
 *        werden, muss hier ein 0-String ('') uebergeben werden.
 * Ergibt:
 *    Die uebersetzte Zeichenkette (den Hex-String)
 *
 */
say "-----------------------------------------------------"
say "CTAPI_StrToHexStr( 'Dieses ist ein Test', '' )"
hex_str = CTAPI_StrToHexStr( "Dieses ist ein Test", '' )
say hex_str
say ''


/*
 * CTAPI_HexStrToStr()
 *
 * Uebersetzt einen 'Hex-String' in eine druckbare Zeichenkette
 *
 * Parameter:
 *     1. Der zu uebersetzender Hex-String
 *     2. (optional) Byte Nummer ab der uebersetzt werden soll
 *     3. (optional) Byte Nummer bis zu der uebersetzt werden soll
 *     4. (optional) Ersatzzeichen fr nicht Druckbar Zeichen
 *        Wenn dieser Parameter nicht angegeben ist wird 0xfa eingesetzt.
 *        Sollen keine Zeichen geaendert werden muss hier ein 0-String ('')
 *        uebergeben werden.
 * Ergibt:
 *    Die uebersetzte Zeichenkette (Den druckbaren Text)
 */
say "-----------------------------------------------------"
say CTAPI_HexStrToStr( "30 01 31 02 32 03 33 04 34 05 35 06 36 07 37 08 38 09 39", 0, 1000 )
/* Bei diesem Beispiel werden die Bytes 0x01, 0x02, ... 0x09 uebersetzt in 0xfa */
Say ''                     
say "CTAPI_StrToHexStr( 'Dieses ist ein Test', '' )"
/*                       |    | | | | | |  | */
/*                       0000000000111111111 */
/*                       0123456789012345678 */
hex_str = CTAPI_StrToHexStr( "Dieses ist ein Test", '' )
say hex_str
say CTAPI_HexStrToStr( hex_str )
say CTAPI_HexStrToStr( hex_str, 0, 5 ) 
say CTAPI_HexStrToStr( hex_str, 7, 9 ) 
say CTAPI_HexStrToStr( hex_str, 11, 13 ) 
say CTAPI_HexStrToStr( hex_str, 15, 18 ) 
say ''


/*
 * CTAPI_SubHexStr()
 *
 * Extrahiert einen Teil 'Hex-String' aus einem 'Hex-String'
 *
 * Parameter:
 *     1. Der Quell 'Hex-String'
 *     2. Start Byte Nr. des zu Extrahierenden Hex-String im Quell Hex-String
 *     3. (optional) Ende Byte Nr. des zu Extrahierenden Hex-String im Quell
 *        Hex-String. Ist dieser Parameter nicht angegeben gilt das letzte 
 *        Byte
 * Ergibt:
 *    Die Zeichenkette (den Hex-String) von Start Byte bis Ende Byte des
 *    Quell Hex-Strings
 *
 */
say "-----------------------------------------------------"
hex_str = '01 02 03 04 05 06 07 08 09 0A'
Say 'CTAPI_SubHexStr(' hex_str ', 2, 4 )'
sub_hex_str = CTAPI_SubHexStr( hex_str, 2, 4 )
say sub_hex_str
say ''


/*
 * CTAPI_HexByteToInt()
 *
 * Ergibt den Integerwert eines Hex Bytes
 *
 * Parameter:
 *     1. Der Quell 'Hex-String' (ein Byte)
 *     2. (optional) Ergebnis soll als Signed=1 oder Unsigned=0 Integer  
 *        zurueckgegeben werden. Wenn dieser Parameter nicht angegeben ist
 *        wird eine Unsigned Integer Zahl zurckgegeben.
 * Ergibt:
 *    Eine Integer Zahl 
 */
say "-----------------------------------------------------"
say "CTAPI_HexByteToInt()"
say '80 ->' CTAPI_HexByteToInt( '80' )
say '80 ->' CTAPI_HexByteToInt( '80', 0 )
say '80 ->' CTAPI_HexByteToInt( '80', 1 )
say '7F ->' CTAPI_HexByteToInt( '7F' )
say '7F ->' CTAPI_HexByteToInt( '7F', 0 )
say '7F ->' CTAPI_HexByteToInt( '7F', 1 )
say ''


/*
 * CTAPI_IntToHexByte()
 *
 * Ergibt ein Hexbyte aus eine Integerzahl
 *
 * Parameter:
 *     1. Eine Integerzahl (0 bis 255) bzw. (-128 bis 127)
 *
 * Ergibt:
 *    Ein Hex Byte
 */
say "-----------------------------------------------------"
say "CTAPI_IntToHexByte()"
say '255 ->' CTAPI_IntToHexByte( 255 )
say '-128 ->' CTAPI_IntToHexByte( -128 )
say '-1 ->' CTAPI_IntToHexByte( -1 )
/* mit D2X lassen sich keine negativen Zahlen bearbeiten */
say '255 ->' d2x( 255 );
/* Die beiden folgenden Ausdrcke fuktionieren nicht */
/* say '-128 ->' d2x( -128 ) */
/* say '-1 ->' d2x( -1 ) */  
say ''


/*
 * CTAPI_XorCheckSum()
 *
 * Berechnet die XOR Prfsumme eines 'Hex_Str' ('A0 B1 22 FF' )
 *
 * Parameter:
 *     1. Ein Hex String
 *
 * Ergibt:
 *     Das Prfsummenbyte 
 *
 */
say "-----------------------------------------------------"
say 'CTAPI_XorCheckSum( CTAPI_StrToHexStr( "Checksum von diesem String", '' ) )'
say 'XOR CheckSum =' CTAPI_XorCheckSum( hex_str )
say ''


/*
 * Aufraeumen
 */
CTAPI_DropAllProc()


