/*
 * (C) A.S. Software, Axel Schmidt, Lehringen 1a, D-27308 Kirchlinteln 2001
 *     http://www.assoftware.de
 *
 * Demonstration der Funktionen fr das CT_API Rexxinterface:
 * 
 *      CTAPI_LoadAllProc()   - Laden der Funktionen
 *      CTAPI_LoadCtApiDll()  - CT_API DLL laden
 *
 *      CTAPI_init()          - entspricht CT_init()
 *      CTAPI_data()          - entspricht CT_data()
 *      CTAPI_close()         - entspricht CT_close()
 *
 *      CTAPI_StrToHexStr()   - siehe example2.cmd
 *      CTAPI_HexStrToStr()   - siehe example2.cmd
 *      CTAPI_SubHexStr()     - siehe example2.cmd
 *      CTAPI_HexByteToInt()  - siehe example2.cmd
 *      CTAPI_IntToHexByte()  - siehe example2.cmd
 */
'@echo off'

/* 
 * Laden aller Proceduren aus CT_REXX 
 */
call RxFuncAdd 'CTAPI_LoadAllProc', 'CT_REXX', 'CTAPI_LoadAllProc'
call CTAPI_LoadAllProc 

/* 
 * Ein paar nuetzliche Konstanten
 */
TRUE = 1
FALSE = 0
HEX = 0
STRING = 1
NO_LE = ''
COM1 = 1
COM2 = 2
COM3 = 3
COM4 = 4


/*
 * Pfad der CT_API DLL  
 */
ct_api_dll_path = 'towitoko.dll' /* towitoko.dll ist im LIBPATH */
/* ct_api_dll_path = 'c:\chipdrive\os2\towitoko.dll' */

/*
 * Schnittstelle mit der das Terminal verbunden ist
 */
port_number = COM1

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/*
 * Laden der CT_API Dll die mit diesen Rexx Prozeduren angesprochen 
 * werden soll.
 */
if( CTAPI_LoadCtApiDll( ct_api_dll_path ) <> 0 ) then do
  say 'Could not Load' ct_api_dll_path'.'
  exit( 1 ) 
end

/*
 * CT_init
 */
card_terminal_number = 10 
rc = CTAPI_init( card_terminal_number, port_number )
if rc <> 0 then do
    say 'CTAPI_init() returns' rc
    card_terminal_number = 0
    call cleanup_and_exit card_terminal_number, FALSE
end 

/* 
 * Reset Terminal 
 */
say 'Reset Terminal'
ct_data_var.cla     = '20'         /* Class-Byte (Hex) */
ct_data_var.ins     = '11'         /* Instruction Byte (hex) */
ct_data_var.p1      = '00'         /* Parameter Byte 1 (hex) */
ct_data_var.p2      = '00'         /* Parameter Byte 2 (hex) */
ct_data_var.indata  = ''           /* Input Datenfeld (Hex Array or String) */
ct_data_var.type    = HEX          /* Type des Datenfeld (hex=0 or string=1) */
ct_data_var.le      = NO_LE        /* Length Expected (hex) ''= No le Byte */
ct_data_var.dad     = 1            /* Destination - Terminal */
ct_data_var.sad     = 2            /* Source - Host */
ct_data_var.lr      = 0            /* Groesse des Datenpuffer (2 - 65535) */
ct_data_var.outdata = ''           /* Rueckgabe Datenfeld (Hex Array or String) */
ct_data_var.sw1sw2  = ''           /* Trailer */ 

rc = CTAPI_data( card_terminal_number, ct_data_var )
if rc <> 0 then do
    say 'CTAPI_data() returns' rc
    call cleanup_and_exit card_terminal_number, TRUE
end
  
say 'Out Data:' ct_data_var.outdata
say 'sw1sw2:' ct_data_var.sw1sw2
say 'lr:' ct_data_var.lr
say 'dad:' ct_data_var.dad
say 'sad:' ct_data_var.sad

/*
 * Request ICC - ATR
 */
say 'Request ICC'
ct_data_var.cla     = '20'         /* Class-Byte (Hex) */
ct_data_var.ins     = '12'         /* Instruction Byte (hex) */
ct_data_var.p1      = '01'         /* Parameter Byte 1 (hex) */
ct_data_var.p2      = '01'         /* Parameter Byte 2 (hex) */
ct_data_var.indata  = ''           /* Input Datenfeld (Hex Array or String) */
ct_data_var.type    = HEX          /* Type des In Datenfeld (hex=0, string=1) */
ct_data_var.le      = 0            /* Length Expected (hex) ''= No le Byte */
ct_data_var.dad     = 1            /* Destination - Terminal */
ct_data_var.sad     = 2            /* Source - Host */
ct_data_var.lr      = 4096         /* Groesse des Datenpuffer (2 - 65535) */
ct_data_var.outdata = ''           /* Rueckgabe Datenfeld (Hex Array or String) */
ct_data_var.sw1sw2  = ''           /* Trailer */ 

rc = CTAPI_data( card_terminal_number, ct_data_var )
if rc <> 0 then do
    say 'CTAPI_data() returns' rc
    call cleanup_and_exit card_terminal_number, TRUE
end
  
say 'Out Data:' ct_data_var.outdata
say 'sw1sw2:' ct_data_var.sw1sw2
say 'lr:' ct_data_var.lr
say 'dad:' ct_data_var.dad
say 'sad:' ct_data_var.sad
  
select
    when ct_data_var.sw1sw2 = '90 00' then say 'Speicherkarte erkannt'
    when ct_data_var.sw1sw2 = '90 01' then say 'Prozessorkarte erkannt'
    when ct_data_var.sw1sw2 = '62 00' then say 'Keine Karte im Terminal'
    when ct_data_var.sw1sw2 = '62 01' then say 'Karte ist in Benutzung'
    when ct_data_var.sw1sw2 = '64 00' then say 'Reset ohne Erfolg'
    when ct_data_var.sw1sw2 = '64 01' then say 'Prozess abgebrochen'
    when ct_data_var.sw1sw2 = '69 00' then say 'Timer Kommando nicht untersttzt'
    otherwise say 'unbekannter Fehler'
end
    

/*
 * Bei einer Speicherkarte werden nun ein paar Bytes eingelesen 
 */
if ct_data_var.sw1sw2 = '90 00' then do 

    /*
     * Read Binary
     */
    say 'Request ICC'
    ct_data_var.cla     = '20'         /* Class-Byte (Hex) */
    ct_data_var.ins     = 'B0'         /* Instruction Byte (hex) */
    ct_data_var.p1      = '00'         /* Parameter Byte 1 (hex) */
    ct_data_var.p2      = '00'         /* Parameter Byte 2 (hex) */
    ct_data_var.indata  = ''           /* Input Datenfeld (Hex Array or String) */
    ct_data_var.type    = HEX          /* Type des In Datenfeld (hex=0, string=1) */
    ct_data_var.le      = 0            /* Length Expected (hex) ''= No le Byte */
    ct_data_var.dad     = 0            /* Destination - Terminal */
    ct_data_var.sad     = 2            /* Source - Host */
    ct_data_var.lr      = 4096         /* Groesse des Datenpuffer */
    ct_data_var.outdata = ''           /* Rueckgabe Datenfeld (Hex Array or String) */
    ct_data_var.sw1sw2  = ''           /* Trailer */ 

    rc = CTAPI_data( card_terminal_number, ct_data_var )
    if rc <> 0 then do
        say 'CTAPI_data() returns' rc
        call cleanup_and_exit card_terminal_number, TRUE
    end
    say 'Out Data (HEX):' ct_data_var.outdata
    say 'Out Data (text):' CTAPI_HexStrToStr( ct_data_var.outdata )  
    say 'sw1sw2:' ct_data_var.sw1sw2
    say 'lr:' ct_data_var.lr
    say 'dad:' ct_data_var.dad
    say 'sad:' ct_data_var.sad

end


/*
 * Close CT-API 
 */
rc = CTAPI_close( card_terminal_number )
if rc <> 0 then do
    say 'CTAPI_close() returns' rc
    call cleanup_and_exit card_terminal_number, FALSE
end  

call CTAPI_FreeCtApiDll
call CTAPI_DropAllProc

exit 0 

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/* Free CT-API Dll */
cleanup_and_exit :
parse arg ctn, ctn_is_open 
if( ctn_is_open = TRUE ) then do
    rc = CTAPI_close( ctn )
end
call CTAPI_FreeCtApiDll
call CTAPI_DropAllProc
exit 1
return

